@@ -1,3 +1,3 @@
 from .Requests import Requests
 from .Config import Config
-from .ownip import get_ip
\ No newline at end of file
+from .ownip import get
\ No newline at end of file
